# `stats_arrays` Changelog

## 0.6.1 (29-07-2019)

* Several bug fixes from Daniel de Koning
* Start improvement of beta distribution

# 0.6 (19-05-2019)

* Allow `MCRandomNumberGenerator` to generate multiple samples at once
* Move tests to pytest
* Add tests for MCRNG

## 0.5.1 (11-05-2019)

* Import from `collections.abc` when possible, for Python 3.8 support.
